@@ -232,22 +232,25 @@ lmDynamic <- function(data, ic=c("AICc","AIC","BIC","BICc"), bruteforce=FALSE, s
 
     # Modify the data and move to the list
     if(is.data.frame(data)){
-        listToCall$data <- cbind(y,model.matrix(cl$formula, data=data[rowsSelected,])[,-1]);
+        listToCall$data <- cbind(y,model.matrix(cl$formula, data=data[rowsSelected,])[,-1,drop=FALSE]);
     }
     else{
-        listToCall$data <- cbind(y,as.data.frame(data[rowsSelected,-1]));
+        listToCall$data <- cbind(y,as.data.frame(data[rowsSelected,-1,drop=FALSE]));
     }
     rm(data);
 
-    # Set alpha for the dalaplace
+    # Other stuff for the things like alpha of ALaplace
+    other <- vector("list",1);
+
+    # Set alpha for the dalaplace. If not provided do alpha=0.5
     if(distribution=="dalaplace"){
-        listToCall$alpha <- ellipsis$alpha;
         if(is.null(ellipsis$alpha)){
             alpha <- 0.5;
         }
         else{
             alpha <- ellipsis$alpha;
         }
+        other$alpha <- listToCall$alpha <- alpha;
     }
 
     # Observations in sample, assuming that the missing values are for the holdout
@@ -282,8 +285,10 @@ lmDynamic <- function(data, ic=c("AICc","AIC","BIC","BICc"), bruteforce=FALSE, s
 
         #Produce matrix with binaries for inclusion of variables in the loop
         variablesCombinations[,1] <- rep(c(0:1),times=prod(variablesBinary[-1]+1));
-        for(i in 2:nVariables){
-            variablesCombinations[,i] <- rep(c(0:variablesBinary[i]),each=prod(variablesBinary[1:(i-1)]+1));
+        if(nVariables>1){
+            for(i in 2:nVariables){
+                variablesCombinations[,i] <- rep(c(0:variablesBinary[i]),each=prod(variablesBinary[1:(i-1)]+1));
+            }
         }
 
         # Vector of ICs
@@ -308,7 +313,7 @@ lmDynamic <- function(data, ic=c("AICc","AIC","BIC","BICc"), bruteforce=FALSE, s
         bestExoNames <- names(coef(ourModel))[-1];
         # If the number of variables is small, do bruteforce
         if(nparam(ourModel)<16){
-            ourModel <- lmDynamic(listToCall$data[,c(responseName,bestExoNames)], ic=ic,
+            ourModel <- lmDynamic(listToCall$data[,c(responseName,bestExoNames),drop=FALSE], ic=ic,
                                    bruteforce=TRUE, silent=silent, distribution=distribution, parallel=parallel, ...);
             ourModel$call <- cl;
             return(ourModel);
@@ -418,7 +423,7 @@ lmDynamic <- function(data, ic=c("AICc","AIC","BIC","BICc"), bruteforce=FALSE, s
                 cat(paste0(rep("\b",nchar(round((i-1)/nCombinations,2)*100)+1),collapse=""));
                 cat(paste0(round(i/nCombinations,2)*100,"%"));
             }
-            listToCall$formula <- as.formula(paste0(responseName,"~",paste0(exoNames[variablesCombinations[i,]==1],collapse="+")));
+            listToCall$formula <- as.formula(paste0(responseName,"~",paste0(exoNames[variablesCombinations[i,,drop=FALSE]==1],collapse="+")));
             ourModel <- do.call(lmCall,listToCall);
 
             pICs[,i] <- IC(ourModel);
@@ -547,7 +552,8 @@ lmDynamic <- function(data, ic=c("AICc","AIC","BIC","BICc"), bruteforce=FALSE, s
                        residuals=as.vector(errors), distribution=distribution, logLik=logLikCombined, IC=ICValue,
                        df.residual=mean(df), df=sum(apply(importance,2,mean))+1, importance=importance,
                        call=cl, rank=nVariables+1, data=listToCall$data, mu=mu, scale=scale,
-                       coefficientsDynamic=parametersWeighted, df.residualDynamic=df, dfDynamic=apply(importance,1,sum)+1);
+                       coefficientsDynamic=parametersWeighted, df.residualDynamic=df, dfDynamic=apply(importance,1,sum)+1,
+                       other=other);
 
     return(structure(finalModel,class=c("greyboxD","alm","greybox")));
 }
