@@ -1,7 +1,8 @@
 #' Regression for Multiple Comparison
 #'
-#' RMC stands for "Regression for Methods Comparison". This is a parametric
-#' test for the comparison of means of several distributions
+#' RMC stands for "Regression for Multiple Comparison", referring to the
+#' comparison of forecasting methods. This is a parametric test for the comparison
+#' of means of several distributions
 #
 #' This test is a parametric counterpart of Nemenyi / MCB test (Demsar, 2006) and
 #' uses asymptotic properties of regression models. It relies on distributional
@@ -10,7 +11,7 @@
 #' them will have symmetrically distributed residuals, thus normal regression can
 #' be used for the parameters estimation.
 #'
-#' The test constructs the regression model of the kind:
+#' The test constructs the regression model of the type:
 #'
 #' y = b' X + e,
 #'
@@ -19,48 +20,44 @@
 #' vector of coefficients for the dummies and e is the error term of the model.
 #'
 #' Depending on the provided data, it might make sense to use different types of
-#' regressions. The function supports Gausian linear regression
-#' (\code{distribution="dnorm"}, when the data is normal), advanced linear regression with
-#' folded normal distribution (\code{distribution="dfnorm"}, for example, absolute errors,
-#' assuming that the original errors are normally distributed) and advanced linear
-#' regression with log normal distribution (\code{distribution="dlnorm"}, which might be
-#' useful in case of relative error measures.
+#' regressions. The default one is the log normal distribution for the relative
+#' error measures. The type of distribution is regulated with \code{distribution}
+#' and is restricted by the values of it from the \link[greybox]{alm} function.
 #'
-#' The advisable error measures to use in the test are RelMAE and RelMSE together with
-#' \code{distribution="dlnorm"}. They are unbiased and their logarithms are
-#' symmetrically distributed (Davydenko & Fildes, 2013). Although their distributions
-#' are not normal, given the typically large samples of datasets, the Central Limit
+#' The advisable error measures to use in the test are relative measures, such as
+#' RelMAE, RelRMSE, RelAME. They are unbiased and their logarithms are symmetrically
+#' distributed (Davydenko & Fildes, 2013). Although their distributions are not log
+#' normal, given the typically large samples of datasets, the Central Limit
 #' Theorem helps in the adequate construction of the confidence intervals for the
 #' parameters.
 #'
 #' The test is equivalent to Nemenyi test, when applied to the ranks of the error
-#' measures on large samples.
+#' measures on large samples with \code{distribution="dnorm"}.
 #'
 #' There is also a \code{plot()} method that allows producing either "mcb" or "lines"
 #' style of plot. This can be regulated via \code{plot(x, outplot="lines")}.
 #
 #' @param data Matrix or data frame with observations in rows and variables in
 #' columns.
-#' @param distribution Type of the distribution to use. If this is a clear forecast error,
-#' then \code{"dnorm"} is appropriate, leading to a simple Gausian linear
-#' regression. \code{"dfnorm"} would lead to a alm model with folded normal
-#' distribution. Finally, \code{"dlnorm"} would lead to the alm with log normal
-#' distribution. This value is passed to \code{alm()} function. You can try some
+#' @param distribution Type of the distribution to use. This value is passed to
+#' \code{alm()} function. \code{"dlnorm"} would lead to the alm with log normal
+#' distribution. If this is a clear forecast error, then \code{"dnorm"} might be
+#' appropriate, leading to a simple Gausian linear regression. \code{"dfnorm"}
+#' would lead to an alm model with folded normal distribution. You can try some
 #' other distributions, but don't expect anything meaningful.
 #' @param level The width of the confidence interval. Default is 0.95.
-#' @param outplot What outplot of plot to use after the calculations. This can be
-#' either "MCB" (\code{"mcb"}) outplot or "Vertical lines" (\code{"lines"}).
+#' @param outplot What type of plot to use after the calculations. This can be
+#' either "MCB" (\code{"mcb"}), or "Vertical lines" (\code{"lines"}), or nothing
+#' (\code{"none"}). You can also use plot method on the produced object in order
+#' to get the same effect.
 #' @param select What column of data to highlight on the plot. If NULL, then
 #' the method with the lowest value is selected.
-#' @param plot If \code{TRUE} then the graph is produced after the calculations.
-#' You can also use plot method on the produced object in order to get the same
-#' effect.
 #' @param ... Other parameters passed to plot function
 #
-#' @return If \code{plot=TRUE}, then the function plots the results after all
+#' @return If \code{outplot!="none"}, then the function plots the results after all
 #' the calculations. In case of \code{distribution="dnorm"}, the closer to zero the
-#' intervals are, the better model performs. When \code{distribution="dfnorm"} or
-#' \code{distribution="dlnorm"}, the lower, the better.
+#' intervals are, the better model performs. When \code{distribution="dlnorm"} or
+#' \code{distribution="dfnorm"}, the lower, the better.
 #'
 #' Function returns a list of a class "rmc", which contains the following
 #' variables:
@@ -70,6 +67,8 @@
 #' \item{vlines}{Coordinates used for outplot="l", marking the groups of methods.}
 #' \item{groups}{The table containing the groups. \code{TRUE} - methods are in the
 #' same group, \code{FALSE} - they are not.}
+#' \item{methods}{Similar to \code{group} parameter, but with a slightly different
+#' presentation.}
 #' \item{p.value}{p-value for the test of the significance of the model. This is a
 #' log-likelihood ratios chi-squared test, comparing the model with the one with
 #' intercept only.}
@@ -143,14 +142,14 @@
 #'
 #' @importFrom stats pchisq
 #' @export rmc
-rmc <- function(data, distribution=c("dnorm","dfnorm","dlnorm"),
-                level=0.95, outplot=c("mcb","lines"), select=NULL, plot=TRUE, ...){
+rmc <- function(data, distribution=c("dlnorm","dnorm","dfnorm"),
+                level=0.95, outplot=c("mcb","lines","none"), select=NULL, ...){
 
     #### This is temporary and needs to be removed at some point! ####
     outplot <- depricator(outplot, list(...));
 
     distribution <- distribution[1];
-    outplot <- substr(outplot[1],1,1);
+    outplot <- match.arg(outplot,c("mcb","lines","none"));
 
     #### Prepare the data ####
     obs <- nrow(data);
@@ -288,22 +287,43 @@ rmc <- function(data, distribution=c("dnorm","dfnorm","dlnorm"),
         groups[c(vlines[i,1]:vlines[i,2]),i] <- TRUE;
     }
 
+    methodGroups <- matrix(TRUE,nMethods,nMethods,
+                           dimnames=list(names(lmCoefs),names(lmCoefs)));
+    for(i in 1:nMethods){
+        for(j in 1:nMethods){
+            methodGroups[i,j] <- ((lmIntervals[i,2] >= lmIntervals[j,1]) & (lmIntervals[i,1] <= lmIntervals[j,1])
+                                  | (lmIntervals[i,2] >= lmIntervals[j,2]) & (lmIntervals[i,1] <= lmIntervals[j,2])
+                                  | (lmIntervals[i,2] <= lmIntervals[j,2]) & (lmIntervals[i,1] >= lmIntervals[j,1]))
+        }
+    }
+
     returnedClass <- structure(list(mean=lmCoefs, interval=lmIntervals, vlines=vlines, groups=groups,
-                                    importance=importance, p.value=p.value, level=level, model=lmModel,
-                                    outplot=outplot, select=select, distribution=distribution),
+                                    methods=methodGroups, importance=importance, p.value=p.value,
+                                    level=level, model=lmModel, outplot=outplot, select=select,
+                                    distribution=distribution),
                                class="rmc");
-    if(plot){
-        plot(returnedClass, ...);
+    if(outplot!="none"){
+        plot(returnedClass, outplot=outplot, ...);
+    }
+    else{
+        returnedClass$outplot[] <- "mcb";
     }
     return(returnedClass);
 }
 
 #' @importFrom graphics axis box
 #' @export
-plot.rmc <- function(x, ...){
+plot.rmc <- function(x, outplot=c("mcb","lines"), ...){
     nMethods <- length(x$mean);
     namesMethods <- names(x$mean);
 
+    if(nMethods>5){
+        las <- 2;
+    }
+    else{
+        las <- 0;
+    }
+
     args <- list(...);
     argsNames <- names(args);
 
@@ -324,7 +344,8 @@ plot.rmc <- function(x, ...){
     }
 
     if(ncol(x$groups)>1){
-        pointCol <- "#0C6385";
+        pointCol <- rep("#0DA0DC", nMethods);
+        pointCol[x$methods[,x$select]] <- "#0C6385";
         lineCol <- "#0DA0DC";
     }
     else{
@@ -332,15 +353,9 @@ plot.rmc <- function(x, ...){
         lineCol <- "grey";
     }
 
-    if(("outplot" %in% argsNames)){
-        outplot <- substr(args$outplot,1,1);
-        args$outplot <- NULL;
-    }
-    else{
-        outplot <- x$outplot;
-    }
+    outplot <- match.arg(outplot,c("mcb","lines"));
 
-    if(outplot=="m"){
+    if(outplot=="mcb"){
         if(!("xlab" %in% argsNames)){
             args$xlab <- "";
         }
@@ -356,33 +371,19 @@ plot.rmc <- function(x, ...){
             args$ylim <- c(args$ylim[1]-0.1,args$ylim[2]+0.1);
         }
 
-        # if(all(parMar==(c(5,4,4,2)+0.1))){
-        #     parMar <- c(2, 2, 0, 0) + 0.1;
-        # }
-        # if(args$main!=""){
-        #     parMar <- parMar + c(0,0,4,0);
-        # }
-        # if(args$ylab!=""){
-        #     parMar <- parMar + c(0,2,0,0);
-        # }
-        # if(args$xlab!=""){
-        #     parMar <- parMar + c(2,0,0,0);
-        # }
-        # par(mar=parMar);
-
         # Use do.call to use manipulated ellipsis (...)
         do.call(plot, args);
         for(i in 1:nMethods){
             lines(rep(i,2),x$interval[i,],col=lineCol,lwd=2);
         }
         points(x$mean, pch=19, col=pointCol);
-        axis(1,c(1:nMethods),namesMethods);
+        axis(1, at=c(1:nMethods), labels=namesMethods, las=las);
         axis(2);
         box(which="plot", col="black");
 
         abline(h=x$interval[x$select,], lwd=2, lty=2, col="grey");
     }
-    else if(outplot=="l"){
+    else if(outplot=="lines"){
         # Save the current par() values
         parDefault <- par(no.readonly=TRUE);
         parMar <- parDefault$mar;
@@ -392,6 +393,7 @@ plot.rmc <- function(x, ...){
         k <- nrow(vlines);
         colours <- c("#0DA0DC","#17850C","#EA3921","#E1C513","#BB6ECE","#5DAD9D");
         colours <- rep(colours,ceiling(k/length(colours)))[1:k];
+        groupElements <- apply(x$groups,2,sum);
 
         labelSize <- max(nchar(namesMethods));
 
@@ -432,9 +434,11 @@ plot.rmc <- function(x, ...){
 
         if(k>1){
             for(i in 1:k){
-                lines(c(i,i), vlines[i,], col=colours[i], lwd = 2);
-                lines(c(0,i), rep(vlines[i,1],times=2), col="gray", lty=2);
-                lines(c(0,i), rep(vlines[i,2],times=2), col="gray", lty=2);
+                if(groupElements[i]>1){
+                    lines(c(i,i), vlines[i,], col=colours[i], lwd = 2);
+                    lines(c(0,i), rep(vlines[i,1],times=2), col="gray", lty=2);
+                    lines(c(0,i), rep(vlines[i,2],times=2), col="gray", lty=2);
+                }
             }
         }
         else{
@@ -442,7 +446,7 @@ plot.rmc <- function(x, ...){
             lines(c(0,1), rep(vlines[1,1],times=2), col=lineCol, lty=2);
             lines(c(0,1), rep(vlines[1,2],times=2), col=lineCol, lty=2);
         }
-        axis(2,c(1:nMethods),namesMethods,las=2);
+        axis(2, at=c(1:nMethods), labels=namesMethods, las=2);
 
         par(parDefault)
     }
